@@ -37,7 +37,7 @@ struct AvMetaReaderGstPrivate {
 static void
 _set_property (GObject *object,
                guint prop_id,
-               const GValue *value,
+               G_GNUC_UNUSED const GValue *value,
                GParamSpec *pspec)
 {
 	G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -46,14 +46,14 @@ _set_property (GObject *object,
 static void
 _get_property (GObject *object,
                guint prop_id,
-               GValue *value,
+               G_GNUC_UNUSED GValue *value,
                GParamSpec *pspec)
 {
 	G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 }
 
 static GOptionGroup *
-_get_option_group (AvMetaReader *reader)
+_get_option_group (G_GNUC_UNUSED AvMetaReader *reader)
 {
 	static GOptionGroup *option_group = NULL;
 
@@ -76,13 +76,13 @@ _get_option_group (AvMetaReader *reader)
 }
 
 static void
-_finalize (GObject *self)
+_finalize (G_GNUC_UNUSED GObject *self)
 {
 	// G_OBJECT_CLASS (av_meta_reader_gst_parent_class)->finalize (self);
 }
 
 static void
-av_meta_reader_gst_class_finalize (AvMetaReaderGstClass *klass)
+av_meta_reader_gst_class_finalize (G_GNUC_UNUSED AvMetaReaderGstClass *klass)
 {
 }
 
@@ -135,11 +135,9 @@ done:
 static void
 _insert_tag (const GstTagList *list, const gchar *tag, DmapAvRecord *record)
 {
-	gint i;
-
 	g_assert (tag);
 
-	for (i = 0; i < gst_tag_list_get_tag_size (list, tag); i++) {
+	for (guint i = 0; i < gst_tag_list_get_tag_size (list, tag); i++) {
 		gchar *val;
 
 		if (G_TYPE_STRING == gst_tag_get_type (tag)) {
@@ -227,7 +225,7 @@ done:
 }
 
 static void
-_on_discovered_cb (GstDiscoverer *discoverer, GstDiscovererInfo *info, GError *error, DmapAvRecord *record)
+_on_discovered_cb (G_GNUC_UNUSED GstDiscoverer *discoverer, GstDiscovererInfo *info, G_GNUC_UNUSED GError *error, DmapAvRecord *record)
 {
 	const gchar *uri;
 	GList *video_streams = NULL;
@@ -267,7 +265,7 @@ done:
 }
 
 static void
-_on_finished_cb (GstDiscoverer *discoverer, AvMetaReaderGstPrivate *priv)
+_on_finished_cb (G_GNUC_UNUSED GstDiscoverer *discoverer, AvMetaReaderGstPrivate *priv)
 {
 	g_main_loop_quit (priv->loop);
 }
@@ -336,7 +334,7 @@ dmapd_module_load (GTypeModule *module)
 }
 
 G_MODULE_EXPORT gboolean
-dmapd_module_unload (GTypeModule *module)
+dmapd_module_unload (G_GNUC_UNUSED GTypeModule *module)
 {
 	return TRUE;
 }
