@@ -22,12 +22,12 @@
 #include "av-meta-reader.h"
 
 static void
-av_meta_reader_init (AvMetaReader *reader)
+av_meta_reader_init (G_GNUC_UNUSED AvMetaReader *reader)
 {
 }
 
 static void
-av_meta_reader_class_init (AvMetaReaderClass *klass)
+av_meta_reader_class_init (G_GNUC_UNUSED AvMetaReaderClass *klass)
 {
 }
 
