@@ -197,22 +197,22 @@ _handle_path(DbBuilderGDir *builder,
 		_monitor_directory (DB_BUILDER_GDIR (builder), path, G_CALLBACK(_file_changed_cb), builder);
 	} else {
 		gchar *location;
-		guint id = 0;
+		guint id = DMAP_DB_ID_BAD;
 
 		location = g_filename_to_uri (path, NULL, NULL);
 		// FIXME: very expensive for BDB module:
 		id = dmap_db_lookup_id_by_location (builder->priv->db, location);
-		ok = id != DMAP_DB_ID_BAD;
 		g_free (location);
 
-		if (! id) {
+		if (DMAP_DB_ID_BAD == id) {
 			id = dmap_db_add_path (builder->priv->db, path, error);
-			ok = id != DMAP_DB_ID_BAD;
-			if (!id) {
+			if (DMAP_DB_ID_BAD == id) {
 				goto done;
 			}
+			ok = TRUE;
 			g_debug ("Done processing %s with id. %u (record #%lu).", path, id, dmap_db_count (builder->priv->db));
 		} else {
+			ok = TRUE;
 			g_debug ("Done processing (cached) %s with id. %u (record #%lu).", path, id, dmap_db_count (builder->priv->db));
 		}
 
@@ -321,7 +321,7 @@ _create_file_idle(gpointer _data)
 	return G_SOURCE_REMOVE;
 }
 
-START_TEST(test_monitor_directory)
+START_TEST(_test_monitor_directory)
 {
 	gchar *tmpdir;
 	GError *error = NULL;
@@ -481,7 +481,7 @@ Suite *db_test_builder_gdir_suite(void)
 	Suite *s = suite_create("db-test-builder-gdir");
 
 	TCase *tc_monitor_directory = tcase_create("test_monitor_directory");
-	tcase_add_test(tc_monitor_directory, test_monitor_directory);
+	tcase_add_test(tc_monitor_directory, _test_monitor_directory);
 	suite_add_tcase(s, tc_monitor_directory);
 
 	return s;
