@@ -22,12 +22,12 @@
 #include "db-builder.h"
 
 static void
-db_builder_init (DbBuilder *builder)
+db_builder_init (G_GNUC_UNUSED DbBuilder *builder)
 {
 }
 
 static void
-db_builder_class_init (DbBuilderClass *klass)
+db_builder_class_init (G_GNUC_UNUSED DbBuilderClass *klass)
 {
 }
 
