@@ -704,7 +704,7 @@ _done:
 
 #ifdef HAVE_CHECK
 
-START_TEST(test_dmapd_daap_record_add_lookup)
+START_TEST(_test_add_lookup)
 {
 	guint id;
         guint64 filesize;
@@ -803,9 +803,9 @@ Suite *dmapd_test_daap_record_suite(void)
 {
         Suite *s = suite_create("dmapd-test-daap-record");
 
-	TCase *tc_dmapd_daap_record_add_lookup = tcase_create("test_dmapd_daap_record_add_lookup");
-	tcase_add_test(tc_dmapd_daap_record_add_lookup, test_dmapd_daap_record_add_lookup);
-	suite_add_tcase(s, tc_dmapd_daap_record_add_lookup);
+	TCase *tc_add_lookup = tcase_create("test_add_lookup");
+	tcase_add_test(tc_add_lookup, _test_add_lookup);
+	suite_add_tcase(s, tc_add_lookup);
 
 	return s;
 }
