@@ -103,7 +103,7 @@ _get_id (DmapContainerRecord *record)
 // NOTE: ignores record parameter.
 static void
 _add_entry (DmapContainerRecord *container_record,
-            DmapRecord *record, gint id, GError **error)
+            G_GNUC_UNUSED DmapRecord *record, gint id, G_GNUC_UNUSED GError **error)
 {
 	DmapdDmapContainerRecordPrivate *priv = 
 		DMAPD_DMAP_CONTAINER_RECORD (container_record)->priv;
@@ -146,15 +146,6 @@ _get_entries (DmapContainerRecord *record)
 	return pair.dest;
 }
 
-static void
-dmapd_dmap_container_record_init (DmapdDmapContainerRecord *record)
-{
-	record->priv = DMAPD_DMAP_CONTAINER_RECORD_GET_PRIVATE (record);
-	record->priv->id = _nextid++;
-	record->priv->entries = NULL;
-	record->priv->full_db = NULL;
-}
-
 static void
 _finalize (GObject *object)
 {
@@ -189,7 +180,7 @@ dmapd_dmap_container_record_class_init (DmapdDmapContainerRecordClass *klass)
 }
 
 static void
-_dmap_container_record_interface_init (gpointer iface, gpointer data)
+_dmap_container_record_interface_init (gpointer iface, G_GNUC_UNUSED gpointer data)
 {
 	DmapContainerRecordInterface *dmap_container_record = iface;
 
@@ -205,3 +196,12 @@ G_DEFINE_TYPE_WITH_CODE (DmapdDmapContainerRecord, dmapd_dmap_container_record,
 			G_IMPLEMENT_INTERFACE (DMAP_TYPE_CONTAINER_RECORD,
 					       _dmap_container_record_interface_init)
                         G_ADD_PRIVATE (DmapdDmapContainerRecord))
+
+static void
+dmapd_dmap_container_record_init (DmapdDmapContainerRecord *record)
+{
+	record->priv = dmapd_dmap_container_record_get_instance_private (record);
+	record->priv->id = _nextid++;
+	record->priv->entries = NULL;
+	record->priv->full_db = NULL;
+}
