@@ -105,12 +105,6 @@ _constructor (GType type,
         return object;
 }
 
-static void
-dmapd_dpap_record_factory_init (DmapdDmapImageRecordFactory *factory)
-{
-	factory->priv = DMAPD_DPAP_RECORD_FACTORY_GET_PRIVATE (factory);
-}
-
 static void
 dmapd_dpap_record_factory_class_init (DmapdDmapImageRecordFactoryClass *klass)
 {
@@ -129,7 +123,7 @@ dmapd_dpap_record_factory_class_init (DmapdDmapImageRecordFactoryClass *klass)
 }
 
 static void
-_dmap_record_factory_interface_init (gpointer iface, gpointer data)
+_dmap_record_factory_interface_init (gpointer iface, G_GNUC_UNUSED gpointer data)
 {
 	DmapRecordFactoryInterface *factory = iface;
 
@@ -142,3 +136,9 @@ G_DEFINE_TYPE_WITH_CODE (DmapdDmapImageRecordFactory, dmapd_dpap_record_factory,
 			 G_IMPLEMENT_INTERFACE (DMAP_TYPE_RECORD_FACTORY,
 					        _dmap_record_factory_interface_init)
                          G_ADD_PRIVATE (DmapdDmapImageRecordFactory))
+
+static void
+dmapd_dpap_record_factory_init (DmapdDmapImageRecordFactory *factory)
+{
+	factory->priv = dmapd_dpap_record_factory_get_instance_private (factory);
+}
