@@ -479,7 +479,7 @@ _serve (protocol_id_t protocol,
 	}
 
 	if (share_def->playlist_dirs) {
-		add_playlists(share_def->playlist_dirs, db, container_db);
+		playlist_add_playlists(share_def->playlist_dirs, db, container_db);
 	}
 
 	_loop = g_main_loop_new (NULL, FALSE);
