@@ -20,6 +20,11 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#ifndef _PLAYLIST_H
+#define _PLAYLIST_H
+
 #include <libdmapsharing/dmap.h>
 
-void add_playlists(gchar **playlist_dirs, DmapDb *db, DmapContainerDb *container_db);
+void playlist_add_playlists(gchar **playlist_dirs, DmapDb *db, DmapContainerDb *container_db);
+
+#endif
