@@ -21,10 +21,12 @@
  */
 
 #include <libdmapsharing/dmap.h>
-#include <sys/types.h>
-#include <sys/stat.h>
+#include <fcntl.h>
 #include <stdio.h>
 #include <string.h>
+#include <sys/stat.h>
+#include <sys/stat.h>
+#include <sys/types.h>
 #include <unistd.h>
 
 #include "util.h"
@@ -94,7 +96,7 @@ _do_transcode (DmapAvRecord *record, gchar *cachepath, gchar* target_mimetype)
 	gssize read_size;
 	gchar buf[BUFSIZ];
 	GError *error = NULL;
-	FILE *outfile = NULL;
+	int outfile = -1;
 	GInputStream *stream = NULL;
 	GInputStream *decoded_stream = NULL;
 	
@@ -118,8 +120,8 @@ _do_transcode (DmapAvRecord *record, gchar *cachepath, gchar* target_mimetype)
 		goto _return;
 	}
 
-	outfile = fopen (cachepath, "w");
-	if (outfile == NULL) {
+	outfile = open (cachepath, O_CREAT | O_WRONLY, 0660);
+	if (-1 == outfile) {
 		 g_warning ("Error opening: %s", cachepath);
 		 goto _return;
 	}
@@ -132,7 +134,7 @@ _do_transcode (DmapAvRecord *record, gchar *cachepath, gchar* target_mimetype)
 						 NULL,
 						&error);
 		if (read_size > 0) {
-			if (fwrite (buf, 1, read_size, outfile) != read_size) {
+			if (write (outfile, buf, read_size) != read_size) {
 				 g_warning ("Error writing transcoded data");
 				 goto _return;
 			}
@@ -144,8 +146,8 @@ _do_transcode (DmapAvRecord *record, gchar *cachepath, gchar* target_mimetype)
 	} while (read_size > 0);
 
 _return:
-	if (NULL != outfile) {
-		fclose (outfile);
+	if (-1 != outfile) {
+		close (outfile);
 	}
 
 	if (NULL != decoded_stream) {
@@ -163,7 +165,7 @@ _return:
  * have no knowledge of the database, db_dir, etc.
  */
 void
-util_gst_transcode_cache (guint id, DmapAvRecord *record, db_dir_and_target_transcode_mimetype_t *df)
+util_gst_transcode_cache (G_GNUC_UNUSED guint id, DmapAvRecord *record, db_dir_and_target_transcode_mimetype_t *df)
 {
 	struct stat statbuf;
 	gboolean has_video = FALSE;
@@ -230,6 +232,7 @@ util_gst_transcode_cache (guint id, DmapAvRecord *record, db_dir_and_target_tran
 	}
 
 	g_object_set (record, "location", cacheuri,
+	                      "original-location", location,
 	                      "format",   format2,
 	                      "filesize", filesize,
 	                       NULL);
